==> enterprisemodules-pg_config-0.7.0.tar.gz: enterprisemodules-pg_config-0.7.0/lib/puppet/type/pg_extension.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type pg_extension.
#
Puppet::Type.newtype(:pg_extension) do
  include EasyType
  include PuppetX::EnterpriseModules::Postgres::Access
  include PuppetX::EnterpriseModules::Postgres::Utilities
  extend PuppetX::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
    With this type you can create,delete and manage Postgres extensions. Here is an example
    on how you could use this:

        pg_extension { 'my_extension@localhost':
          ensure            => 'present',
        }

    The `pg_extension` type recognises all of the options you also have when using SQL to create a user or a role.
  DOC

  ensurable

  to_get_raw_resources do
    sql_on_cluster_databases <<-SQL
    select
      e.extname as name,
      e.extversion as version,
      a.rolname as owner,
      p.nspname as namespace
    from pg_extension e, 	pg_authid a, pg_namespace p
    where a.oid = e.extowner
    and p.oid = e.extnamespace
    SQL
  end

  on_create do
    [:sql, "create extension #{extension_name}", { :db => db }]
  end

  on_modify do
    [:sql, "alter extension #{extension_name}", { :skip_without_properties => true, :db => db }]
  end

  on_destroy do
    [:sql, "drop extension #{extension_name}", { :db => db }]
  end

  map_title_to_db(:extension_name)

  parameter :name
  parameter :extension_name
  parameter :db

  #   property :oid
  property :schema
  property :version
end

==> enterprisemodules-pg_config-0.11.0.tar.gz: enterprisemodules-pg_config-0.11.0/lib/puppet/type/pg_extension.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type pg_extension.
#
Puppet::Type.newtype(:pg_extension) do
  include EasyType
  include PuppetX::EnterpriseModules::Postgres::Access
  include PuppetX::EnterpriseModules::Postgres::Utilities
  extend PuppetX::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
    With this type you can create,delete and manage Postgres extensions. Here is an example
    on how you could use this:

        pg_extension { 'my_extension@instance':
          ensure            => 'present',
        }

    The `pg_extension` type recognises all of the options you also have when using SQL to create a user or a role.
  DOC

  ensurable

  to_get_raw_resources do
    sql_on_cluster_databases <<-SQL
    select
      e.extname as name,
      e.extversion as version,
      a.rolname as owner,
      p.nspname as namespace
    from pg_extension e, 	pg_authid a, pg_namespace p
    where a.oid = e.extowner
    and p.oid = e.extnamespace
    SQL
  end

  on_create do
    [:sql, "create extension #{extension_name}", { :instance => self[:instance], :db => 'postgres' }]
  end

  on_modify do
    [:sql, "alter extension #{extension_name}", { :skip_without_properties => true, :instance => self[:instance], :db => 'postgres' }]
  end

  on_destroy do
    [:sql, "drop extension #{extension_name}", { :instance => self[:instance], :db => 'postgres' }]
  end

  map_title_to_instance(:extension_name)

  parameter :name
  parameter :extension_name
  parameter :instance

  #   property :oid
  property :schema
  property :version
end
